# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.personal_financial_management_api import PersonalFinancialManagementApi  # noqa: E501
from proton_api.rest import ApiException


class TestPersonalFinancialManagementApi(unittest.TestCase):
    """PersonalFinancialManagementApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.personal_financial_management_api.PersonalFinancialManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_budget_calculator(self):
        """Test case for budget_calculator

        Budget Calculator  # noqa: E501
        """
        pass

    def test_cash_flow_analysis(self):
        """Test case for cash_flow_analysis

        Cash Flow Analysis  # noqa: E501
        """
        pass

    def test_fee_analysis(self):
        """Test case for fee_analysis

        RFee Analysis  # noqa: E501
        """
        pass

    def test_financial_picture(self):
        """Test case for financial_picture

        Financial Picture  # noqa: E501
        """
        pass

    def test_recurring_transaction_analysis(self):
        """Test case for recurring_transaction_analysis

        Recurring Transaction Analysis  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from proton_api.api_client import ApiClient


class BusinessFinancialManagementApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def business_financial_health_check(self, business_financial_health_check_request, **kwargs):  # noqa: E501
        """Business Financial Health Check  # noqa: E501

        Calculate a series of financial ratios to assess business financial health  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_financial_health_check(business_financial_health_check_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessFinancialHealthCheckRequest business_financial_health_check_request: Request payload for Business Financial Health Check (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_financial_health_check_with_http_info(business_financial_health_check_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_financial_health_check_with_http_info(business_financial_health_check_request, **kwargs)  # noqa: E501
            return data

    def business_financial_health_check_with_http_info(self, business_financial_health_check_request, **kwargs):  # noqa: E501
        """Business Financial Health Check  # noqa: E501

        Calculate a series of financial ratios to assess business financial health  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_financial_health_check_with_http_info(business_financial_health_check_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessFinancialHealthCheckRequest business_financial_health_check_request: Request payload for Business Financial Health Check (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['business_financial_health_check_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_financial_health_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'business_financial_health_check_request' is set
        if ('business_financial_health_check_request' not in params or
                params['business_financial_health_check_request'] is None):
            raise ValueError("Missing the required parameter `business_financial_health_check_request` when calling `business_financial_health_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_financial_health_check_request' in params:
            body_params = params['business_financial_health_check_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/business/financial_health_check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cash_analysis(self, cash_analysis_request, **kwargs):  # noqa: E501
        """Cash Analysis  # noqa: E501

        Analyze cash activity over time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cash_analysis(cash_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CashAnalysisRequest cash_analysis_request: Request payload for Cash Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cash_analysis_with_http_info(cash_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.cash_analysis_with_http_info(cash_analysis_request, **kwargs)  # noqa: E501
            return data

    def cash_analysis_with_http_info(self, cash_analysis_request, **kwargs):  # noqa: E501
        """Cash Analysis  # noqa: E501

        Analyze cash activity over time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cash_analysis_with_http_info(cash_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CashAnalysisRequest cash_analysis_request: Request payload for Cash Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cash_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cash_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cash_analysis_request' is set
        if ('cash_analysis_request' not in params or
                params['cash_analysis_request'] is None):
            raise ValueError("Missing the required parameter `cash_analysis_request` when calling `cash_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cash_analysis_request' in params:
            body_params = params['cash_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/business/cash_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def customer_analysis(self, customer_analysis_request, **kwargs):  # noqa: E501
        """Customer Analysis  # noqa: E501

        Analyze customer revenues over a time period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_analysis(customer_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomerAnalysisRequest customer_analysis_request: Request payload for Customer Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.customer_analysis_with_http_info(customer_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_analysis_with_http_info(customer_analysis_request, **kwargs)  # noqa: E501
            return data

    def customer_analysis_with_http_info(self, customer_analysis_request, **kwargs):  # noqa: E501
        """Customer Analysis  # noqa: E501

        Analyze customer revenues over a time period  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_analysis_with_http_info(customer_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustomerAnalysisRequest customer_analysis_request: Request payload for Customer Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method customer_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_analysis_request' is set
        if ('customer_analysis_request' not in params or
                params['customer_analysis_request'] is None):
            raise ValueError("Missing the required parameter `customer_analysis_request` when calling `customer_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'customer_analysis_request' in params:
            body_params = params['customer_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/business/customer_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def financial_statement_analysis(self, financial_statement_analysis_request, **kwargs):  # noqa: E501
        """Financial Statement Analysis  # noqa: E501

        Analyze financial statement accounting data for a business  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.financial_statement_analysis(financial_statement_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FinancialStatementAnalysisRequest financial_statement_analysis_request: Request payload for Financial Statement Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.financial_statement_analysis_with_http_info(financial_statement_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.financial_statement_analysis_with_http_info(financial_statement_analysis_request, **kwargs)  # noqa: E501
            return data

    def financial_statement_analysis_with_http_info(self, financial_statement_analysis_request, **kwargs):  # noqa: E501
        """Financial Statement Analysis  # noqa: E501

        Analyze financial statement accounting data for a business  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.financial_statement_analysis_with_http_info(financial_statement_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FinancialStatementAnalysisRequest financial_statement_analysis_request: Request payload for Financial Statement Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['financial_statement_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method financial_statement_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'financial_statement_analysis_request' is set
        if ('financial_statement_analysis_request' not in params or
                params['financial_statement_analysis_request'] is None):
            raise ValueError("Missing the required parameter `financial_statement_analysis_request` when calling `financial_statement_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'financial_statement_analysis_request' in params:
            body_params = params['financial_statement_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/business/financial_statement_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoice_analysis(self, invoice_analysis_request, **kwargs):  # noqa: E501
        """Invoice Analysis  # noqa: E501

        Analyze invoices to understand the context of money owed and paid to a business  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoice_analysis(invoice_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessInvoiceAnalysisRequest invoice_analysis_request: Request payload for Invoice Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoice_analysis_with_http_info(invoice_analysis_request, **kwargs)  # noqa: E501
        else:
            (data) = self.invoice_analysis_with_http_info(invoice_analysis_request, **kwargs)  # noqa: E501
            return data

    def invoice_analysis_with_http_info(self, invoice_analysis_request, **kwargs):  # noqa: E501
        """Invoice Analysis  # noqa: E501

        Analyze invoices to understand the context of money owed and paid to a business  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoice_analysis_with_http_info(invoice_analysis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessInvoiceAnalysisRequest invoice_analysis_request: Request payload for Invoice Analysis (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invoice_analysis_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoice_analysis" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invoice_analysis_request' is set
        if ('invoice_analysis_request' not in params or
                params['invoice_analysis_request'] is None):
            raise ValueError("Missing the required parameter `invoice_analysis_request` when calling `invoice_analysis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'invoice_analysis_request' in params:
            body_params = params['invoice_analysis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/business/invoice_analysis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FinancialStatementAnalysisRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'period_length': 'str',
        'period_month': 'int',
        'end_date': 'date',
        'client_id': 'str',
        'accounting_method': 'str',
        'period_year': 'int',
        'currency_conversion': 'str',
        'history_frequency_interval': 'str',
        'start_date': 'date',
        'period_type': 'str',
        'currency_code': 'str',
        'show_history': 'bool',
        'stat_names': 'list[str]',
        'period_quarter': 'int',
        'statement_type': 'str'
    }

    attribute_map = {
        'period_length': 'period_length',
        'period_month': 'period_month',
        'end_date': 'end_date',
        'client_id': 'client_id',
        'accounting_method': 'accounting_method',
        'period_year': 'period_year',
        'currency_conversion': 'currency_conversion',
        'history_frequency_interval': 'history_frequency_interval',
        'start_date': 'start_date',
        'period_type': 'period_type',
        'currency_code': 'currency_code',
        'show_history': 'show_history',
        'stat_names': 'stat_names',
        'period_quarter': 'period_quarter',
        'statement_type': 'statement_type'
    }

    def __init__(self, period_length='quarterly', period_month=None, end_date=None, client_id=None, accounting_method=None, period_year=None, currency_conversion=None, history_frequency_interval='month', start_date=None, period_type=None, currency_code=None, show_history=False, stat_names=None, period_quarter=None, statement_type='all'):  # noqa: E501
        """FinancialStatementAnalysisRequest - a model defined in Swagger"""  # noqa: E501

        self._period_length = None
        self._period_month = None
        self._end_date = None
        self._client_id = None
        self._accounting_method = None
        self._period_year = None
        self._currency_conversion = None
        self._history_frequency_interval = None
        self._start_date = None
        self._period_type = None
        self._currency_code = None
        self._show_history = None
        self._stat_names = None
        self._period_quarter = None
        self._statement_type = None
        self.discriminator = None

        if period_length is not None:
            self.period_length = period_length
        if period_month is not None:
            self.period_month = period_month
        if end_date is not None:
            self.end_date = end_date
        if client_id is not None:
            self.client_id = client_id
        self.accounting_method = accounting_method
        if period_year is not None:
            self.period_year = period_year
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if history_frequency_interval is not None:
            self.history_frequency_interval = history_frequency_interval
        if start_date is not None:
            self.start_date = start_date
        if period_type is not None:
            self.period_type = period_type
        if currency_code is not None:
            self.currency_code = currency_code
        if show_history is not None:
            self.show_history = show_history
        if stat_names is not None:
            self.stat_names = stat_names
        if period_quarter is not None:
            self.period_quarter = period_quarter
        if statement_type is not None:
            self.statement_type = statement_type

    @property
    def period_length(self):
        """Gets the period_length of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The period_length of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_length

    @period_length.setter
    def period_length(self, period_length):
        """Sets the period_length of this FinancialStatementAnalysisRequest.


        :param period_length: The period_length of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["annual", "quarterly", "monthly", "ytd", "qtd", "mtd"]  # noqa: E501
        if period_length not in allowed_values:
            raise ValueError(
                "Invalid value for `period_length` ({0}), must be one of {1}"  # noqa: E501
                .format(period_length, allowed_values)
            )

        self._period_length = period_length

    @property
    def period_month(self):
        """Gets the period_month of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The period_month of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: int
        """
        return self._period_month

    @period_month.setter
    def period_month(self, period_month):
        """Sets the period_month of this FinancialStatementAnalysisRequest.


        :param period_month: The period_month of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: int
        """
        if period_month is not None and period_month > 12:  # noqa: E501
            raise ValueError("Invalid value for `period_month`, must be a value less than or equal to `12`")  # noqa: E501
        if period_month is not None and period_month < 1:  # noqa: E501
            raise ValueError("Invalid value for `period_month`, must be a value greater than or equal to `1`")  # noqa: E501

        self._period_month = period_month

    @property
    def end_date(self):
        """Gets the end_date of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The end_date of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this FinancialStatementAnalysisRequest.


        :param end_date: The end_date of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def client_id(self):
        """Gets the client_id of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The client_id of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this FinancialStatementAnalysisRequest.


        :param client_id: The client_id of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def accounting_method(self):
        """Gets the accounting_method of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The accounting_method of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._accounting_method

    @accounting_method.setter
    def accounting_method(self, accounting_method):
        """Sets the accounting_method of this FinancialStatementAnalysisRequest.


        :param accounting_method: The accounting_method of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """
        if accounting_method is None:
            raise ValueError("Invalid value for `accounting_method`, must not be `None`")  # noqa: E501
        allowed_values = ["accrual", "cash"]  # noqa: E501
        if accounting_method not in allowed_values:
            raise ValueError(
                "Invalid value for `accounting_method` ({0}), must be one of {1}"  # noqa: E501
                .format(accounting_method, allowed_values)
            )

        self._accounting_method = accounting_method

    @property
    def period_year(self):
        """Gets the period_year of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The period_year of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: int
        """
        return self._period_year

    @period_year.setter
    def period_year(self, period_year):
        """Sets the period_year of this FinancialStatementAnalysisRequest.


        :param period_year: The period_year of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: int
        """

        self._period_year = period_year

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The currency_conversion of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this FinancialStatementAnalysisRequest.


        :param currency_conversion: The currency_conversion of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def history_frequency_interval(self):
        """Gets the history_frequency_interval of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The history_frequency_interval of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._history_frequency_interval

    @history_frequency_interval.setter
    def history_frequency_interval(self, history_frequency_interval):
        """Sets the history_frequency_interval of this FinancialStatementAnalysisRequest.


        :param history_frequency_interval: The history_frequency_interval of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["day", "week", "month", "quarter", "year"]  # noqa: E501
        if history_frequency_interval not in allowed_values:
            raise ValueError(
                "Invalid value for `history_frequency_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(history_frequency_interval, allowed_values)
            )

        self._history_frequency_interval = history_frequency_interval

    @property
    def start_date(self):
        """Gets the start_date of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The start_date of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this FinancialStatementAnalysisRequest.


        :param start_date: The start_date of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def period_type(self):
        """Gets the period_type of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The period_type of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_type

    @period_type.setter
    def period_type(self, period_type):
        """Sets the period_type of this FinancialStatementAnalysisRequest.


        :param period_type: The period_type of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["calendar", "fiscal"]  # noqa: E501
        if period_type not in allowed_values:
            raise ValueError(
                "Invalid value for `period_type` ({0}), must be one of {1}"  # noqa: E501
                .format(period_type, allowed_values)
            )

        self._period_type = period_type

    @property
    def currency_code(self):
        """Gets the currency_code of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The currency_code of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this FinancialStatementAnalysisRequest.


        :param currency_code: The currency_code of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def show_history(self):
        """Gets the show_history of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The show_history of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_history

    @show_history.setter
    def show_history(self, show_history):
        """Sets the show_history of this FinancialStatementAnalysisRequest.


        :param show_history: The show_history of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: bool
        """

        self._show_history = show_history

    @property
    def stat_names(self):
        """Gets the stat_names of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The stat_names of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._stat_names

    @stat_names.setter
    def stat_names(self, stat_names):
        """Sets the stat_names of this FinancialStatementAnalysisRequest.


        :param stat_names: The stat_names of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["cash", "accounts_receivable", "total_assets", "accounts_payable", "total_liabilities", "total_equity", "total_revenue", "cogs", "total_expenses", "operating_income", "gross_profit", "net_income", "ebitda"]  # noqa: E501
        if not set(stat_names).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `stat_names` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(stat_names) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._stat_names = stat_names

    @property
    def period_quarter(self):
        """Gets the period_quarter of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The period_quarter of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: int
        """
        return self._period_quarter

    @period_quarter.setter
    def period_quarter(self, period_quarter):
        """Sets the period_quarter of this FinancialStatementAnalysisRequest.


        :param period_quarter: The period_quarter of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: int
        """
        if period_quarter is not None and period_quarter > 4:  # noqa: E501
            raise ValueError("Invalid value for `period_quarter`, must be a value less than or equal to `4`")  # noqa: E501
        if period_quarter is not None and period_quarter < 1:  # noqa: E501
            raise ValueError("Invalid value for `period_quarter`, must be a value greater than or equal to `1`")  # noqa: E501

        self._period_quarter = period_quarter

    @property
    def statement_type(self):
        """Gets the statement_type of this FinancialStatementAnalysisRequest.  # noqa: E501


        :return: The statement_type of this FinancialStatementAnalysisRequest.  # noqa: E501
        :rtype: str
        """
        return self._statement_type

    @statement_type.setter
    def statement_type(self, statement_type):
        """Sets the statement_type of this FinancialStatementAnalysisRequest.


        :param statement_type: The statement_type of this FinancialStatementAnalysisRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["income_statement", "balance_sheet", "all"]  # noqa: E501
        if statement_type not in allowed_values:
            raise ValueError(
                "Invalid value for `statement_type` ({0}), must be one of {1}"  # noqa: E501
                .format(statement_type, allowed_values)
            )

        self._statement_type = statement_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FinancialStatementAnalysisRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FinancialStatementAnalysisRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GoalDecumulationAllocationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'thresh_type': 'str',
        'goal_id': 'str',
        'client_id': 'str',
        'conf_tgt': 'float',
        'risk_score': 'float',
        'remove_outliers': 'bool',
        'allocation_priority': 'str',
        'a_horizon': 'int',
        'withdrawal_config': 'list[GoalWithdrawalConfig]',
        'market_data_source': 'str',
        'compounding_rate': 'float',
        'adjust_for_compounding': 'bool',
        'opt_config': 'OptConfig',
        'deposit_config': 'list[DecumulationGoalDepositConfig]',
        'use_proxy_data': 'bool',
        'thresh': 'float',
        'horizon_frequency': 'str',
        'recommendation_config': 'RecommendationConfig',
        'create_log': 'bool',
        'withdrawal_tax': 'float',
        'trading_days_per_year': 'int',
        'allocations': 'list[str]',
        'n': 'int',
        'd_horizon': 'int',
        'curr_inv': 'float',
        'recommend_type': 'str',
        'allocation_method': 'str'
    }

    attribute_map = {
        'thresh_type': 'thresh_type',
        'goal_id': 'goal_id',
        'client_id': 'client_id',
        'conf_tgt': 'conf_tgt',
        'risk_score': 'risk_score',
        'remove_outliers': 'remove_outliers',
        'allocation_priority': 'allocation_priority',
        'a_horizon': 'a_horizon',
        'withdrawal_config': 'withdrawal_config',
        'market_data_source': 'market_data_source',
        'compounding_rate': 'compounding_rate',
        'adjust_for_compounding': 'adjust_for_compounding',
        'opt_config': 'opt_config',
        'deposit_config': 'deposit_config',
        'use_proxy_data': 'use_proxy_data',
        'thresh': 'thresh',
        'horizon_frequency': 'horizon_frequency',
        'recommendation_config': 'recommendation_config',
        'create_log': 'create_log',
        'withdrawal_tax': 'withdrawal_tax',
        'trading_days_per_year': 'trading_days_per_year',
        'allocations': 'allocations',
        'n': 'n',
        'd_horizon': 'd_horizon',
        'curr_inv': 'curr_inv',
        'recommend_type': 'recommend_type',
        'allocation_method': 'allocation_method'
    }

    def __init__(self, thresh_type='perc', goal_id=None, client_id=None, conf_tgt=0.9, risk_score=None, remove_outliers=True, allocation_priority=None, a_horizon=None, withdrawal_config=None, market_data_source='nucleus', compounding_rate=0.0, adjust_for_compounding=False, opt_config=None, deposit_config=None, use_proxy_data=False, thresh=None, horizon_frequency='year', recommendation_config=None, create_log=False, withdrawal_tax=0.0, trading_days_per_year=252, allocations=None, n=1000, d_horizon=None, curr_inv=None, recommend_type='horizon', allocation_method=None):  # noqa: E501
        """GoalDecumulationAllocationRequest - a model defined in Swagger"""  # noqa: E501

        self._thresh_type = None
        self._goal_id = None
        self._client_id = None
        self._conf_tgt = None
        self._risk_score = None
        self._remove_outliers = None
        self._allocation_priority = None
        self._a_horizon = None
        self._withdrawal_config = None
        self._market_data_source = None
        self._compounding_rate = None
        self._adjust_for_compounding = None
        self._opt_config = None
        self._deposit_config = None
        self._use_proxy_data = None
        self._thresh = None
        self._horizon_frequency = None
        self._recommendation_config = None
        self._create_log = None
        self._withdrawal_tax = None
        self._trading_days_per_year = None
        self._allocations = None
        self._n = None
        self._d_horizon = None
        self._curr_inv = None
        self._recommend_type = None
        self._allocation_method = None
        self.discriminator = None

        if thresh_type is not None:
            self.thresh_type = thresh_type
        if goal_id is not None:
            self.goal_id = goal_id
        if client_id is not None:
            self.client_id = client_id
        if conf_tgt is not None:
            self.conf_tgt = conf_tgt
        if risk_score is not None:
            self.risk_score = risk_score
        if remove_outliers is not None:
            self.remove_outliers = remove_outliers
        self.allocation_priority = allocation_priority
        if a_horizon is not None:
            self.a_horizon = a_horizon
        if withdrawal_config is not None:
            self.withdrawal_config = withdrawal_config
        if market_data_source is not None:
            self.market_data_source = market_data_source
        if compounding_rate is not None:
            self.compounding_rate = compounding_rate
        if adjust_for_compounding is not None:
            self.adjust_for_compounding = adjust_for_compounding
        if opt_config is not None:
            self.opt_config = opt_config
        if deposit_config is not None:
            self.deposit_config = deposit_config
        if use_proxy_data is not None:
            self.use_proxy_data = use_proxy_data
        if thresh is not None:
            self.thresh = thresh
        if horizon_frequency is not None:
            self.horizon_frequency = horizon_frequency
        if recommendation_config is not None:
            self.recommendation_config = recommendation_config
        if create_log is not None:
            self.create_log = create_log
        if withdrawal_tax is not None:
            self.withdrawal_tax = withdrawal_tax
        if trading_days_per_year is not None:
            self.trading_days_per_year = trading_days_per_year
        if allocations is not None:
            self.allocations = allocations
        if n is not None:
            self.n = n
        if d_horizon is not None:
            self.d_horizon = d_horizon
        if curr_inv is not None:
            self.curr_inv = curr_inv
        if recommend_type is not None:
            self.recommend_type = recommend_type
        self.allocation_method = allocation_method

    @property
    def thresh_type(self):
        """Gets the thresh_type of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The thresh_type of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._thresh_type

    @thresh_type.setter
    def thresh_type(self, thresh_type):
        """Sets the thresh_type of this GoalDecumulationAllocationRequest.


        :param thresh_type: The thresh_type of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["amnt", "perc"]  # noqa: E501
        if thresh_type not in allowed_values:
            raise ValueError(
                "Invalid value for `thresh_type` ({0}), must be one of {1}"  # noqa: E501
                .format(thresh_type, allowed_values)
            )

        self._thresh_type = thresh_type

    @property
    def goal_id(self):
        """Gets the goal_id of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The goal_id of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._goal_id

    @goal_id.setter
    def goal_id(self, goal_id):
        """Sets the goal_id of this GoalDecumulationAllocationRequest.


        :param goal_id: The goal_id of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """

        self._goal_id = goal_id

    @property
    def client_id(self):
        """Gets the client_id of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The client_id of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this GoalDecumulationAllocationRequest.


        :param client_id: The client_id of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def conf_tgt(self):
        """Gets the conf_tgt of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The conf_tgt of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._conf_tgt

    @conf_tgt.setter
    def conf_tgt(self, conf_tgt):
        """Sets the conf_tgt of this GoalDecumulationAllocationRequest.


        :param conf_tgt: The conf_tgt of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: float
        """
        if conf_tgt is not None and conf_tgt > 1:  # noqa: E501
            raise ValueError("Invalid value for `conf_tgt`, must be a value less than or equal to `1`")  # noqa: E501
        if conf_tgt is not None and conf_tgt < 0:  # noqa: E501
            raise ValueError("Invalid value for `conf_tgt`, must be a value greater than or equal to `0`")  # noqa: E501

        self._conf_tgt = conf_tgt

    @property
    def risk_score(self):
        """Gets the risk_score of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The risk_score of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._risk_score

    @risk_score.setter
    def risk_score(self, risk_score):
        """Sets the risk_score of this GoalDecumulationAllocationRequest.


        :param risk_score: The risk_score of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: float
        """
        if risk_score is not None and risk_score > 100:  # noqa: E501
            raise ValueError("Invalid value for `risk_score`, must be a value less than or equal to `100`")  # noqa: E501
        if risk_score is not None and risk_score < 0:  # noqa: E501
            raise ValueError("Invalid value for `risk_score`, must be a value greater than or equal to `0`")  # noqa: E501

        self._risk_score = risk_score

    @property
    def remove_outliers(self):
        """Gets the remove_outliers of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The remove_outliers of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._remove_outliers

    @remove_outliers.setter
    def remove_outliers(self, remove_outliers):
        """Sets the remove_outliers of this GoalDecumulationAllocationRequest.


        :param remove_outliers: The remove_outliers of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: bool
        """

        self._remove_outliers = remove_outliers

    @property
    def allocation_priority(self):
        """Gets the allocation_priority of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The allocation_priority of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_priority

    @allocation_priority.setter
    def allocation_priority(self, allocation_priority):
        """Sets the allocation_priority of this GoalDecumulationAllocationRequest.


        :param allocation_priority: The allocation_priority of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """
        if allocation_priority is None:
            raise ValueError("Invalid value for `allocation_priority`, must not be `None`")  # noqa: E501
        allowed_values = ["goal", "risk"]  # noqa: E501
        if allocation_priority not in allowed_values:
            raise ValueError(
                "Invalid value for `allocation_priority` ({0}), must be one of {1}"  # noqa: E501
                .format(allocation_priority, allowed_values)
            )

        self._allocation_priority = allocation_priority

    @property
    def a_horizon(self):
        """Gets the a_horizon of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The a_horizon of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: int
        """
        return self._a_horizon

    @a_horizon.setter
    def a_horizon(self, a_horizon):
        """Sets the a_horizon of this GoalDecumulationAllocationRequest.


        :param a_horizon: The a_horizon of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: int
        """
        if a_horizon is not None and a_horizon > 350:  # noqa: E501
            raise ValueError("Invalid value for `a_horizon`, must be a value less than or equal to `350`")  # noqa: E501
        if a_horizon is not None and a_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `a_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._a_horizon = a_horizon

    @property
    def withdrawal_config(self):
        """Gets the withdrawal_config of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The withdrawal_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: list[GoalWithdrawalConfig]
        """
        return self._withdrawal_config

    @withdrawal_config.setter
    def withdrawal_config(self, withdrawal_config):
        """Sets the withdrawal_config of this GoalDecumulationAllocationRequest.


        :param withdrawal_config: The withdrawal_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: list[GoalWithdrawalConfig]
        """

        self._withdrawal_config = withdrawal_config

    @property
    def market_data_source(self):
        """Gets the market_data_source of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The market_data_source of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._market_data_source

    @market_data_source.setter
    def market_data_source(self, market_data_source):
        """Sets the market_data_source of this GoalDecumulationAllocationRequest.


        :param market_data_source: The market_data_source of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["nucleus", "integration"]  # noqa: E501
        if market_data_source not in allowed_values:
            raise ValueError(
                "Invalid value for `market_data_source` ({0}), must be one of {1}"  # noqa: E501
                .format(market_data_source, allowed_values)
            )

        self._market_data_source = market_data_source

    @property
    def compounding_rate(self):
        """Gets the compounding_rate of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The compounding_rate of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._compounding_rate

    @compounding_rate.setter
    def compounding_rate(self, compounding_rate):
        """Sets the compounding_rate of this GoalDecumulationAllocationRequest.


        :param compounding_rate: The compounding_rate of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: float
        """
        if compounding_rate is not None and compounding_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `compounding_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._compounding_rate = compounding_rate

    @property
    def adjust_for_compounding(self):
        """Gets the adjust_for_compounding of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The adjust_for_compounding of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._adjust_for_compounding

    @adjust_for_compounding.setter
    def adjust_for_compounding(self, adjust_for_compounding):
        """Sets the adjust_for_compounding of this GoalDecumulationAllocationRequest.


        :param adjust_for_compounding: The adjust_for_compounding of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: bool
        """

        self._adjust_for_compounding = adjust_for_compounding

    @property
    def opt_config(self):
        """Gets the opt_config of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The opt_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: OptConfig
        """
        return self._opt_config

    @opt_config.setter
    def opt_config(self, opt_config):
        """Sets the opt_config of this GoalDecumulationAllocationRequest.


        :param opt_config: The opt_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: OptConfig
        """

        self._opt_config = opt_config

    @property
    def deposit_config(self):
        """Gets the deposit_config of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The deposit_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: list[DecumulationGoalDepositConfig]
        """
        return self._deposit_config

    @deposit_config.setter
    def deposit_config(self, deposit_config):
        """Sets the deposit_config of this GoalDecumulationAllocationRequest.


        :param deposit_config: The deposit_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: list[DecumulationGoalDepositConfig]
        """

        self._deposit_config = deposit_config

    @property
    def use_proxy_data(self):
        """Gets the use_proxy_data of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The use_proxy_data of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_proxy_data

    @use_proxy_data.setter
    def use_proxy_data(self, use_proxy_data):
        """Sets the use_proxy_data of this GoalDecumulationAllocationRequest.


        :param use_proxy_data: The use_proxy_data of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: bool
        """

        self._use_proxy_data = use_proxy_data

    @property
    def thresh(self):
        """Gets the thresh of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The thresh of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._thresh

    @thresh.setter
    def thresh(self, thresh):
        """Sets the thresh of this GoalDecumulationAllocationRequest.


        :param thresh: The thresh of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: float
        """
        if thresh is not None and thresh < 0:  # noqa: E501
            raise ValueError("Invalid value for `thresh`, must be a value greater than or equal to `0`")  # noqa: E501

        self._thresh = thresh

    @property
    def horizon_frequency(self):
        """Gets the horizon_frequency of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The horizon_frequency of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._horizon_frequency

    @horizon_frequency.setter
    def horizon_frequency(self, horizon_frequency):
        """Sets the horizon_frequency of this GoalDecumulationAllocationRequest.


        :param horizon_frequency: The horizon_frequency of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "six_months", "quarter", "month", "two_weeks", "week", "day"]  # noqa: E501
        if horizon_frequency not in allowed_values:
            raise ValueError(
                "Invalid value for `horizon_frequency` ({0}), must be one of {1}"  # noqa: E501
                .format(horizon_frequency, allowed_values)
            )

        self._horizon_frequency = horizon_frequency

    @property
    def recommendation_config(self):
        """Gets the recommendation_config of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The recommendation_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: RecommendationConfig
        """
        return self._recommendation_config

    @recommendation_config.setter
    def recommendation_config(self, recommendation_config):
        """Sets the recommendation_config of this GoalDecumulationAllocationRequest.


        :param recommendation_config: The recommendation_config of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: RecommendationConfig
        """

        self._recommendation_config = recommendation_config

    @property
    def create_log(self):
        """Gets the create_log of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The create_log of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this GoalDecumulationAllocationRequest.


        :param create_log: The create_log of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def withdrawal_tax(self):
        """Gets the withdrawal_tax of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The withdrawal_tax of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._withdrawal_tax

    @withdrawal_tax.setter
    def withdrawal_tax(self, withdrawal_tax):
        """Sets the withdrawal_tax of this GoalDecumulationAllocationRequest.


        :param withdrawal_tax: The withdrawal_tax of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: float
        """
        if withdrawal_tax is not None and withdrawal_tax > 1:  # noqa: E501
            raise ValueError("Invalid value for `withdrawal_tax`, must be a value less than or equal to `1`")  # noqa: E501
        if withdrawal_tax is not None and withdrawal_tax < 0:  # noqa: E501
            raise ValueError("Invalid value for `withdrawal_tax`, must be a value greater than or equal to `0`")  # noqa: E501

        self._withdrawal_tax = withdrawal_tax

    @property
    def trading_days_per_year(self):
        """Gets the trading_days_per_year of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The trading_days_per_year of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: int
        """
        return self._trading_days_per_year

    @trading_days_per_year.setter
    def trading_days_per_year(self, trading_days_per_year):
        """Sets the trading_days_per_year of this GoalDecumulationAllocationRequest.


        :param trading_days_per_year: The trading_days_per_year of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: int
        """
        if trading_days_per_year is not None and trading_days_per_year > 365:  # noqa: E501
            raise ValueError("Invalid value for `trading_days_per_year`, must be a value less than or equal to `365`")  # noqa: E501
        if trading_days_per_year is not None and trading_days_per_year < 1:  # noqa: E501
            raise ValueError("Invalid value for `trading_days_per_year`, must be a value greater than or equal to `1`")  # noqa: E501

        self._trading_days_per_year = trading_days_per_year

    @property
    def allocations(self):
        """Gets the allocations of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The allocations of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocations

    @allocations.setter
    def allocations(self, allocations):
        """Sets the allocations of this GoalDecumulationAllocationRequest.


        :param allocations: The allocations of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: list[str]
        """

        self._allocations = allocations

    @property
    def n(self):
        """Gets the n of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The n of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: int
        """
        return self._n

    @n.setter
    def n(self, n):
        """Sets the n of this GoalDecumulationAllocationRequest.


        :param n: The n of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: int
        """
        if n is not None and n > 10000:  # noqa: E501
            raise ValueError("Invalid value for `n`, must be a value less than or equal to `10000`")  # noqa: E501
        if n is not None and n < 1:  # noqa: E501
            raise ValueError("Invalid value for `n`, must be a value greater than or equal to `1`")  # noqa: E501

        self._n = n

    @property
    def d_horizon(self):
        """Gets the d_horizon of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The d_horizon of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: int
        """
        return self._d_horizon

    @d_horizon.setter
    def d_horizon(self, d_horizon):
        """Sets the d_horizon of this GoalDecumulationAllocationRequest.


        :param d_horizon: The d_horizon of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: int
        """
        if d_horizon is not None and d_horizon > 350:  # noqa: E501
            raise ValueError("Invalid value for `d_horizon`, must be a value less than or equal to `350`")  # noqa: E501
        if d_horizon is not None and d_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `d_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._d_horizon = d_horizon

    @property
    def curr_inv(self):
        """Gets the curr_inv of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The curr_inv of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: float
        """
        return self._curr_inv

    @curr_inv.setter
    def curr_inv(self, curr_inv):
        """Sets the curr_inv of this GoalDecumulationAllocationRequest.


        :param curr_inv: The curr_inv of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: float
        """
        if curr_inv is not None and curr_inv < 0:  # noqa: E501
            raise ValueError("Invalid value for `curr_inv`, must be a value greater than or equal to `0`")  # noqa: E501

        self._curr_inv = curr_inv

    @property
    def recommend_type(self):
        """Gets the recommend_type of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The recommend_type of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._recommend_type

    @recommend_type.setter
    def recommend_type(self, recommend_type):
        """Sets the recommend_type of this GoalDecumulationAllocationRequest.


        :param recommend_type: The recommend_type of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["recurring", "one-time", "combo", "horizon"]  # noqa: E501
        if recommend_type not in allowed_values:
            raise ValueError(
                "Invalid value for `recommend_type` ({0}), must be one of {1}"  # noqa: E501
                .format(recommend_type, allowed_values)
            )

        self._recommend_type = recommend_type

    @property
    def allocation_method(self):
        """Gets the allocation_method of this GoalDecumulationAllocationRequest.  # noqa: E501


        :return: The allocation_method of this GoalDecumulationAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_method

    @allocation_method.setter
    def allocation_method(self, allocation_method):
        """Sets the allocation_method of this GoalDecumulationAllocationRequest.


        :param allocation_method: The allocation_method of this GoalDecumulationAllocationRequest.  # noqa: E501
        :type: str
        """
        if allocation_method is None:
            raise ValueError("Invalid value for `allocation_method`, must not be `None`")  # noqa: E501
        allowed_values = ["select", "create"]  # noqa: E501
        if allocation_method not in allowed_values:
            raise ValueError(
                "Invalid value for `allocation_method` ({0}), must be one of {1}"  # noqa: E501
                .format(allocation_method, allowed_values)
            )

        self._allocation_method = allocation_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GoalDecumulationAllocationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GoalDecumulationAllocationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FinancialHealthCheckRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gross_annual_income': 'float',
        'liquid_assets': 'float',
        'net_monthly_income': 'float',
        'client_id': 'str',
        'short_term_liabilities': 'float',
        'monthly_expenses': 'float',
        'total_liabilities': 'float',
        'lookback_periods': 'int',
        'ratio_targets': 'RatioTargets',
        'non_liquid_assets': 'float'
    }

    attribute_map = {
        'gross_annual_income': 'gross_annual_income',
        'liquid_assets': 'liquid_assets',
        'net_monthly_income': 'net_monthly_income',
        'client_id': 'client_id',
        'short_term_liabilities': 'short_term_liabilities',
        'monthly_expenses': 'monthly_expenses',
        'total_liabilities': 'total_liabilities',
        'lookback_periods': 'lookback_periods',
        'ratio_targets': 'ratio_targets',
        'non_liquid_assets': 'non_liquid_assets'
    }

    def __init__(self, gross_annual_income=None, liquid_assets=None, net_monthly_income=None, client_id=None, short_term_liabilities=None, monthly_expenses=None, total_liabilities=None, lookback_periods=3, ratio_targets=None, non_liquid_assets=None):  # noqa: E501
        """FinancialHealthCheckRequest - a model defined in Swagger"""  # noqa: E501

        self._gross_annual_income = None
        self._liquid_assets = None
        self._net_monthly_income = None
        self._client_id = None
        self._short_term_liabilities = None
        self._monthly_expenses = None
        self._total_liabilities = None
        self._lookback_periods = None
        self._ratio_targets = None
        self._non_liquid_assets = None
        self.discriminator = None

        if gross_annual_income is not None:
            self.gross_annual_income = gross_annual_income
        if liquid_assets is not None:
            self.liquid_assets = liquid_assets
        if net_monthly_income is not None:
            self.net_monthly_income = net_monthly_income
        if client_id is not None:
            self.client_id = client_id
        if short_term_liabilities is not None:
            self.short_term_liabilities = short_term_liabilities
        if monthly_expenses is not None:
            self.monthly_expenses = monthly_expenses
        if total_liabilities is not None:
            self.total_liabilities = total_liabilities
        if lookback_periods is not None:
            self.lookback_periods = lookback_periods
        if ratio_targets is not None:
            self.ratio_targets = ratio_targets
        if non_liquid_assets is not None:
            self.non_liquid_assets = non_liquid_assets

    @property
    def gross_annual_income(self):
        """Gets the gross_annual_income of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The gross_annual_income of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._gross_annual_income

    @gross_annual_income.setter
    def gross_annual_income(self, gross_annual_income):
        """Sets the gross_annual_income of this FinancialHealthCheckRequest.


        :param gross_annual_income: The gross_annual_income of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if gross_annual_income is not None and gross_annual_income < 0:  # noqa: E501
            raise ValueError("Invalid value for `gross_annual_income`, must be a value greater than or equal to `0`")  # noqa: E501

        self._gross_annual_income = gross_annual_income

    @property
    def liquid_assets(self):
        """Gets the liquid_assets of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The liquid_assets of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._liquid_assets

    @liquid_assets.setter
    def liquid_assets(self, liquid_assets):
        """Sets the liquid_assets of this FinancialHealthCheckRequest.


        :param liquid_assets: The liquid_assets of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if liquid_assets is not None and liquid_assets < 0:  # noqa: E501
            raise ValueError("Invalid value for `liquid_assets`, must be a value greater than or equal to `0`")  # noqa: E501

        self._liquid_assets = liquid_assets

    @property
    def net_monthly_income(self):
        """Gets the net_monthly_income of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The net_monthly_income of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._net_monthly_income

    @net_monthly_income.setter
    def net_monthly_income(self, net_monthly_income):
        """Sets the net_monthly_income of this FinancialHealthCheckRequest.


        :param net_monthly_income: The net_monthly_income of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if net_monthly_income is not None and net_monthly_income < 0:  # noqa: E501
            raise ValueError("Invalid value for `net_monthly_income`, must be a value greater than or equal to `0`")  # noqa: E501

        self._net_monthly_income = net_monthly_income

    @property
    def client_id(self):
        """Gets the client_id of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The client_id of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this FinancialHealthCheckRequest.


        :param client_id: The client_id of this FinancialHealthCheckRequest.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def short_term_liabilities(self):
        """Gets the short_term_liabilities of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The short_term_liabilities of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._short_term_liabilities

    @short_term_liabilities.setter
    def short_term_liabilities(self, short_term_liabilities):
        """Sets the short_term_liabilities of this FinancialHealthCheckRequest.


        :param short_term_liabilities: The short_term_liabilities of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if short_term_liabilities is not None and short_term_liabilities < 0:  # noqa: E501
            raise ValueError("Invalid value for `short_term_liabilities`, must be a value greater than or equal to `0`")  # noqa: E501

        self._short_term_liabilities = short_term_liabilities

    @property
    def monthly_expenses(self):
        """Gets the monthly_expenses of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The monthly_expenses of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._monthly_expenses

    @monthly_expenses.setter
    def monthly_expenses(self, monthly_expenses):
        """Sets the monthly_expenses of this FinancialHealthCheckRequest.


        :param monthly_expenses: The monthly_expenses of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if monthly_expenses is not None and monthly_expenses < 0:  # noqa: E501
            raise ValueError("Invalid value for `monthly_expenses`, must be a value greater than or equal to `0`")  # noqa: E501

        self._monthly_expenses = monthly_expenses

    @property
    def total_liabilities(self):
        """Gets the total_liabilities of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The total_liabilities of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_liabilities

    @total_liabilities.setter
    def total_liabilities(self, total_liabilities):
        """Sets the total_liabilities of this FinancialHealthCheckRequest.


        :param total_liabilities: The total_liabilities of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if total_liabilities is not None and total_liabilities < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_liabilities`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_liabilities = total_liabilities

    @property
    def lookback_periods(self):
        """Gets the lookback_periods of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The lookback_periods of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: int
        """
        return self._lookback_periods

    @lookback_periods.setter
    def lookback_periods(self, lookback_periods):
        """Sets the lookback_periods of this FinancialHealthCheckRequest.


        :param lookback_periods: The lookback_periods of this FinancialHealthCheckRequest.  # noqa: E501
        :type: int
        """
        if lookback_periods is not None and lookback_periods < 1:  # noqa: E501
            raise ValueError("Invalid value for `lookback_periods`, must be a value greater than or equal to `1`")  # noqa: E501

        self._lookback_periods = lookback_periods

    @property
    def ratio_targets(self):
        """Gets the ratio_targets of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The ratio_targets of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: RatioTargets
        """
        return self._ratio_targets

    @ratio_targets.setter
    def ratio_targets(self, ratio_targets):
        """Sets the ratio_targets of this FinancialHealthCheckRequest.


        :param ratio_targets: The ratio_targets of this FinancialHealthCheckRequest.  # noqa: E501
        :type: RatioTargets
        """

        self._ratio_targets = ratio_targets

    @property
    def non_liquid_assets(self):
        """Gets the non_liquid_assets of this FinancialHealthCheckRequest.  # noqa: E501


        :return: The non_liquid_assets of this FinancialHealthCheckRequest.  # noqa: E501
        :rtype: float
        """
        return self._non_liquid_assets

    @non_liquid_assets.setter
    def non_liquid_assets(self, non_liquid_assets):
        """Sets the non_liquid_assets of this FinancialHealthCheckRequest.


        :param non_liquid_assets: The non_liquid_assets of this FinancialHealthCheckRequest.  # noqa: E501
        :type: float
        """
        if non_liquid_assets is not None and non_liquid_assets < 0:  # noqa: E501
            raise ValueError("Invalid value for `non_liquid_assets`, must be a value greater than or equal to `0`")  # noqa: E501

        self._non_liquid_assets = non_liquid_assets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FinancialHealthCheckRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FinancialHealthCheckRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SensitivityFactor(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'change_duration': 'int',
        'lag': 'int',
        'change_amount': 'float',
        'ticker': 'str'
    }

    attribute_map = {
        'change_duration': 'change_duration',
        'lag': 'lag',
        'change_amount': 'change_amount',
        'ticker': 'ticker'
    }

    def __init__(self, change_duration=None, lag=0, change_amount=None, ticker=None):  # noqa: E501
        """SensitivityFactor - a model defined in Swagger"""  # noqa: E501

        self._change_duration = None
        self._lag = None
        self._change_amount = None
        self._ticker = None
        self.discriminator = None

        self.change_duration = change_duration
        if lag is not None:
            self.lag = lag
        self.change_amount = change_amount
        self.ticker = ticker

    @property
    def change_duration(self):
        """Gets the change_duration of this SensitivityFactor.  # noqa: E501


        :return: The change_duration of this SensitivityFactor.  # noqa: E501
        :rtype: int
        """
        return self._change_duration

    @change_duration.setter
    def change_duration(self, change_duration):
        """Sets the change_duration of this SensitivityFactor.


        :param change_duration: The change_duration of this SensitivityFactor.  # noqa: E501
        :type: int
        """
        if change_duration is None:
            raise ValueError("Invalid value for `change_duration`, must not be `None`")  # noqa: E501
        if change_duration is not None and change_duration < 1:  # noqa: E501
            raise ValueError("Invalid value for `change_duration`, must be a value greater than or equal to `1`")  # noqa: E501

        self._change_duration = change_duration

    @property
    def lag(self):
        """Gets the lag of this SensitivityFactor.  # noqa: E501


        :return: The lag of this SensitivityFactor.  # noqa: E501
        :rtype: int
        """
        return self._lag

    @lag.setter
    def lag(self, lag):
        """Sets the lag of this SensitivityFactor.


        :param lag: The lag of this SensitivityFactor.  # noqa: E501
        :type: int
        """
        if lag is not None and lag < 0:  # noqa: E501
            raise ValueError("Invalid value for `lag`, must be a value greater than or equal to `0`")  # noqa: E501

        self._lag = lag

    @property
    def change_amount(self):
        """Gets the change_amount of this SensitivityFactor.  # noqa: E501


        :return: The change_amount of this SensitivityFactor.  # noqa: E501
        :rtype: float
        """
        return self._change_amount

    @change_amount.setter
    def change_amount(self, change_amount):
        """Sets the change_amount of this SensitivityFactor.


        :param change_amount: The change_amount of this SensitivityFactor.  # noqa: E501
        :type: float
        """
        if change_amount is None:
            raise ValueError("Invalid value for `change_amount`, must not be `None`")  # noqa: E501
        if change_amount is not None and change_amount < -1:  # noqa: E501
            raise ValueError("Invalid value for `change_amount`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._change_amount = change_amount

    @property
    def ticker(self):
        """Gets the ticker of this SensitivityFactor.  # noqa: E501


        :return: The ticker of this SensitivityFactor.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this SensitivityFactor.


        :param ticker: The ticker of this SensitivityFactor.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SensitivityFactor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SensitivityFactor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PurchaseCalculatorDepositAmountRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'purchase_amount': 'float',
        'aggregation_account_ids': 'list[str]',
        'current_savings': 'float',
        'account_ids': 'list[str]',
        'investment_tax': 'float',
        'purchase_horizon': 'int',
        'inflation_rate': 'float',
        'horizon_frequency_interval': 'str',
        'portfolio_return': 'float',
        'deposit_schedule': 'CalculatorDepositSchedule'
    }

    attribute_map = {
        'purchase_amount': 'purchase_amount',
        'aggregation_account_ids': 'aggregation_account_ids',
        'current_savings': 'current_savings',
        'account_ids': 'account_ids',
        'investment_tax': 'investment_tax',
        'purchase_horizon': 'purchase_horizon',
        'inflation_rate': 'inflation_rate',
        'horizon_frequency_interval': 'horizon_frequency_interval',
        'portfolio_return': 'portfolio_return',
        'deposit_schedule': 'deposit_schedule'
    }

    def __init__(self, purchase_amount=None, aggregation_account_ids=None, current_savings=0.0, account_ids=None, investment_tax=0.0, purchase_horizon=None, inflation_rate=0.0, horizon_frequency_interval='year', portfolio_return=None, deposit_schedule=None):  # noqa: E501
        """PurchaseCalculatorDepositAmountRequest - a model defined in Swagger"""  # noqa: E501

        self._purchase_amount = None
        self._aggregation_account_ids = None
        self._current_savings = None
        self._account_ids = None
        self._investment_tax = None
        self._purchase_horizon = None
        self._inflation_rate = None
        self._horizon_frequency_interval = None
        self._portfolio_return = None
        self._deposit_schedule = None
        self.discriminator = None

        self.purchase_amount = purchase_amount
        if aggregation_account_ids is not None:
            self.aggregation_account_ids = aggregation_account_ids
        if current_savings is not None:
            self.current_savings = current_savings
        if account_ids is not None:
            self.account_ids = account_ids
        if investment_tax is not None:
            self.investment_tax = investment_tax
        self.purchase_horizon = purchase_horizon
        if inflation_rate is not None:
            self.inflation_rate = inflation_rate
        if horizon_frequency_interval is not None:
            self.horizon_frequency_interval = horizon_frequency_interval
        self.portfolio_return = portfolio_return
        if deposit_schedule is not None:
            self.deposit_schedule = deposit_schedule

    @property
    def purchase_amount(self):
        """Gets the purchase_amount of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The purchase_amount of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._purchase_amount

    @purchase_amount.setter
    def purchase_amount(self, purchase_amount):
        """Sets the purchase_amount of this PurchaseCalculatorDepositAmountRequest.


        :param purchase_amount: The purchase_amount of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: float
        """
        if purchase_amount is None:
            raise ValueError("Invalid value for `purchase_amount`, must not be `None`")  # noqa: E501
        if purchase_amount is not None and purchase_amount < 0:  # noqa: E501
            raise ValueError("Invalid value for `purchase_amount`, must be a value greater than or equal to `0`")  # noqa: E501

        self._purchase_amount = purchase_amount

    @property
    def aggregation_account_ids(self):
        """Gets the aggregation_account_ids of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The aggregation_account_ids of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregation_account_ids

    @aggregation_account_ids.setter
    def aggregation_account_ids(self, aggregation_account_ids):
        """Sets the aggregation_account_ids of this PurchaseCalculatorDepositAmountRequest.


        :param aggregation_account_ids: The aggregation_account_ids of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: list[str]
        """

        self._aggregation_account_ids = aggregation_account_ids

    @property
    def current_savings(self):
        """Gets the current_savings of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The current_savings of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._current_savings

    @current_savings.setter
    def current_savings(self, current_savings):
        """Sets the current_savings of this PurchaseCalculatorDepositAmountRequest.


        :param current_savings: The current_savings of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: float
        """
        if current_savings is not None and current_savings < 0:  # noqa: E501
            raise ValueError("Invalid value for `current_savings`, must be a value greater than or equal to `0`")  # noqa: E501

        self._current_savings = current_savings

    @property
    def account_ids(self):
        """Gets the account_ids of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The account_ids of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this PurchaseCalculatorDepositAmountRequest.


        :param account_ids: The account_ids of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: list[str]
        """

        self._account_ids = account_ids

    @property
    def investment_tax(self):
        """Gets the investment_tax of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The investment_tax of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._investment_tax

    @investment_tax.setter
    def investment_tax(self, investment_tax):
        """Sets the investment_tax of this PurchaseCalculatorDepositAmountRequest.


        :param investment_tax: The investment_tax of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: float
        """
        if investment_tax is not None and investment_tax > 1:  # noqa: E501
            raise ValueError("Invalid value for `investment_tax`, must be a value less than or equal to `1`")  # noqa: E501
        if investment_tax is not None and investment_tax < 0:  # noqa: E501
            raise ValueError("Invalid value for `investment_tax`, must be a value greater than or equal to `0`")  # noqa: E501

        self._investment_tax = investment_tax

    @property
    def purchase_horizon(self):
        """Gets the purchase_horizon of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The purchase_horizon of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: int
        """
        return self._purchase_horizon

    @purchase_horizon.setter
    def purchase_horizon(self, purchase_horizon):
        """Sets the purchase_horizon of this PurchaseCalculatorDepositAmountRequest.


        :param purchase_horizon: The purchase_horizon of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: int
        """
        if purchase_horizon is None:
            raise ValueError("Invalid value for `purchase_horizon`, must not be `None`")  # noqa: E501
        if purchase_horizon is not None and purchase_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `purchase_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._purchase_horizon = purchase_horizon

    @property
    def inflation_rate(self):
        """Gets the inflation_rate of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The inflation_rate of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._inflation_rate

    @inflation_rate.setter
    def inflation_rate(self, inflation_rate):
        """Sets the inflation_rate of this PurchaseCalculatorDepositAmountRequest.


        :param inflation_rate: The inflation_rate of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: float
        """
        if inflation_rate is not None and inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._inflation_rate = inflation_rate

    @property
    def horizon_frequency_interval(self):
        """Gets the horizon_frequency_interval of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The horizon_frequency_interval of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._horizon_frequency_interval

    @horizon_frequency_interval.setter
    def horizon_frequency_interval(self, horizon_frequency_interval):
        """Sets the horizon_frequency_interval of this PurchaseCalculatorDepositAmountRequest.


        :param horizon_frequency_interval: The horizon_frequency_interval of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "quarter", "month", "week"]  # noqa: E501
        if horizon_frequency_interval not in allowed_values:
            raise ValueError(
                "Invalid value for `horizon_frequency_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(horizon_frequency_interval, allowed_values)
            )

        self._horizon_frequency_interval = horizon_frequency_interval

    @property
    def portfolio_return(self):
        """Gets the portfolio_return of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The portfolio_return of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._portfolio_return

    @portfolio_return.setter
    def portfolio_return(self, portfolio_return):
        """Sets the portfolio_return of this PurchaseCalculatorDepositAmountRequest.


        :param portfolio_return: The portfolio_return of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: float
        """
        if portfolio_return is None:
            raise ValueError("Invalid value for `portfolio_return`, must not be `None`")  # noqa: E501
        if portfolio_return is not None and portfolio_return < -1:  # noqa: E501
            raise ValueError("Invalid value for `portfolio_return`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._portfolio_return = portfolio_return

    @property
    def deposit_schedule(self):
        """Gets the deposit_schedule of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501


        :return: The deposit_schedule of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :rtype: CalculatorDepositSchedule
        """
        return self._deposit_schedule

    @deposit_schedule.setter
    def deposit_schedule(self, deposit_schedule):
        """Sets the deposit_schedule of this PurchaseCalculatorDepositAmountRequest.


        :param deposit_schedule: The deposit_schedule of this PurchaseCalculatorDepositAmountRequest.  # noqa: E501
        :type: CalculatorDepositSchedule
        """

        self._deposit_schedule = deposit_schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PurchaseCalculatorDepositAmountRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PurchaseCalculatorDepositAmountRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AnnuityCalculatorAccumulationHorizonRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annuity_amount': 'float',
        'aggregation_account_ids': 'list[str]',
        'tax_rate': 'float',
        'account_ids': 'list[str]',
        'initial_balance': 'float',
        'create_log': 'bool',
        'inflation_rate': 'float',
        'decumulation_horizon': 'int',
        'accumulation_horizon': 'int',
        'annuity_frequency_interval': 'str',
        'portfolio_return': 'float',
        'deposit_schedule': 'AnnuityDepositSchedule'
    }

    attribute_map = {
        'annuity_amount': 'annuity_amount',
        'aggregation_account_ids': 'aggregation_account_ids',
        'tax_rate': 'tax_rate',
        'account_ids': 'account_ids',
        'initial_balance': 'initial_balance',
        'create_log': 'create_log',
        'inflation_rate': 'inflation_rate',
        'decumulation_horizon': 'decumulation_horizon',
        'accumulation_horizon': 'accumulation_horizon',
        'annuity_frequency_interval': 'annuity_frequency_interval',
        'portfolio_return': 'portfolio_return',
        'deposit_schedule': 'deposit_schedule'
    }

    def __init__(self, annuity_amount=None, aggregation_account_ids=None, tax_rate=0.0, account_ids=None, initial_balance=0.0, create_log=False, inflation_rate=0.0, decumulation_horizon=None, accumulation_horizon=None, annuity_frequency_interval='year', portfolio_return=None, deposit_schedule=None):  # noqa: E501
        """AnnuityCalculatorAccumulationHorizonRequest - a model defined in Swagger"""  # noqa: E501

        self._annuity_amount = None
        self._aggregation_account_ids = None
        self._tax_rate = None
        self._account_ids = None
        self._initial_balance = None
        self._create_log = None
        self._inflation_rate = None
        self._decumulation_horizon = None
        self._accumulation_horizon = None
        self._annuity_frequency_interval = None
        self._portfolio_return = None
        self._deposit_schedule = None
        self.discriminator = None

        self.annuity_amount = annuity_amount
        if aggregation_account_ids is not None:
            self.aggregation_account_ids = aggregation_account_ids
        if tax_rate is not None:
            self.tax_rate = tax_rate
        if account_ids is not None:
            self.account_ids = account_ids
        if initial_balance is not None:
            self.initial_balance = initial_balance
        if create_log is not None:
            self.create_log = create_log
        if inflation_rate is not None:
            self.inflation_rate = inflation_rate
        self.decumulation_horizon = decumulation_horizon
        if accumulation_horizon is not None:
            self.accumulation_horizon = accumulation_horizon
        if annuity_frequency_interval is not None:
            self.annuity_frequency_interval = annuity_frequency_interval
        self.portfolio_return = portfolio_return
        if deposit_schedule is not None:
            self.deposit_schedule = deposit_schedule

    @property
    def annuity_amount(self):
        """Gets the annuity_amount of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The annuity_amount of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: float
        """
        return self._annuity_amount

    @annuity_amount.setter
    def annuity_amount(self, annuity_amount):
        """Sets the annuity_amount of this AnnuityCalculatorAccumulationHorizonRequest.


        :param annuity_amount: The annuity_amount of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: float
        """
        if annuity_amount is None:
            raise ValueError("Invalid value for `annuity_amount`, must not be `None`")  # noqa: E501
        if annuity_amount is not None and annuity_amount < 0:  # noqa: E501
            raise ValueError("Invalid value for `annuity_amount`, must be a value greater than or equal to `0`")  # noqa: E501

        self._annuity_amount = annuity_amount

    @property
    def aggregation_account_ids(self):
        """Gets the aggregation_account_ids of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The aggregation_account_ids of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregation_account_ids

    @aggregation_account_ids.setter
    def aggregation_account_ids(self, aggregation_account_ids):
        """Sets the aggregation_account_ids of this AnnuityCalculatorAccumulationHorizonRequest.


        :param aggregation_account_ids: The aggregation_account_ids of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: list[str]
        """

        self._aggregation_account_ids = aggregation_account_ids

    @property
    def tax_rate(self):
        """Gets the tax_rate of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The tax_rate of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: float
        """
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, tax_rate):
        """Sets the tax_rate of this AnnuityCalculatorAccumulationHorizonRequest.


        :param tax_rate: The tax_rate of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: float
        """
        if tax_rate is not None and tax_rate > 1:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value less than or equal to `1`")  # noqa: E501
        if tax_rate is not None and tax_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._tax_rate = tax_rate

    @property
    def account_ids(self):
        """Gets the account_ids of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The account_ids of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this AnnuityCalculatorAccumulationHorizonRequest.


        :param account_ids: The account_ids of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: list[str]
        """

        self._account_ids = account_ids

    @property
    def initial_balance(self):
        """Gets the initial_balance of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The initial_balance of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: float
        """
        return self._initial_balance

    @initial_balance.setter
    def initial_balance(self, initial_balance):
        """Sets the initial_balance of this AnnuityCalculatorAccumulationHorizonRequest.


        :param initial_balance: The initial_balance of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: float
        """
        if initial_balance is not None and initial_balance < 0:  # noqa: E501
            raise ValueError("Invalid value for `initial_balance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._initial_balance = initial_balance

    @property
    def create_log(self):
        """Gets the create_log of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The create_log of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this AnnuityCalculatorAccumulationHorizonRequest.


        :param create_log: The create_log of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def inflation_rate(self):
        """Gets the inflation_rate of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The inflation_rate of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: float
        """
        return self._inflation_rate

    @inflation_rate.setter
    def inflation_rate(self, inflation_rate):
        """Sets the inflation_rate of this AnnuityCalculatorAccumulationHorizonRequest.


        :param inflation_rate: The inflation_rate of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: float
        """
        if inflation_rate is not None and inflation_rate > 20:  # noqa: E501
            raise ValueError("Invalid value for `inflation_rate`, must be a value less than or equal to `20`")  # noqa: E501
        if inflation_rate is not None and inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._inflation_rate = inflation_rate

    @property
    def decumulation_horizon(self):
        """Gets the decumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The decumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: int
        """
        return self._decumulation_horizon

    @decumulation_horizon.setter
    def decumulation_horizon(self, decumulation_horizon):
        """Sets the decumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.


        :param decumulation_horizon: The decumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: int
        """
        if decumulation_horizon is None:
            raise ValueError("Invalid value for `decumulation_horizon`, must not be `None`")  # noqa: E501
        if decumulation_horizon is not None and decumulation_horizon < 1:  # noqa: E501
            raise ValueError("Invalid value for `decumulation_horizon`, must be a value greater than or equal to `1`")  # noqa: E501

        self._decumulation_horizon = decumulation_horizon

    @property
    def accumulation_horizon(self):
        """Gets the accumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The accumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: int
        """
        return self._accumulation_horizon

    @accumulation_horizon.setter
    def accumulation_horizon(self, accumulation_horizon):
        """Sets the accumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.


        :param accumulation_horizon: The accumulation_horizon of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: int
        """
        if accumulation_horizon is not None and accumulation_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `accumulation_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._accumulation_horizon = accumulation_horizon

    @property
    def annuity_frequency_interval(self):
        """Gets the annuity_frequency_interval of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The annuity_frequency_interval of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: str
        """
        return self._annuity_frequency_interval

    @annuity_frequency_interval.setter
    def annuity_frequency_interval(self, annuity_frequency_interval):
        """Sets the annuity_frequency_interval of this AnnuityCalculatorAccumulationHorizonRequest.


        :param annuity_frequency_interval: The annuity_frequency_interval of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["year", "quarter", "month", "week", "day"]  # noqa: E501
        if annuity_frequency_interval not in allowed_values:
            raise ValueError(
                "Invalid value for `annuity_frequency_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(annuity_frequency_interval, allowed_values)
            )

        self._annuity_frequency_interval = annuity_frequency_interval

    @property
    def portfolio_return(self):
        """Gets the portfolio_return of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The portfolio_return of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: float
        """
        return self._portfolio_return

    @portfolio_return.setter
    def portfolio_return(self, portfolio_return):
        """Sets the portfolio_return of this AnnuityCalculatorAccumulationHorizonRequest.


        :param portfolio_return: The portfolio_return of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: float
        """
        if portfolio_return is None:
            raise ValueError("Invalid value for `portfolio_return`, must not be `None`")  # noqa: E501

        self._portfolio_return = portfolio_return

    @property
    def deposit_schedule(self):
        """Gets the deposit_schedule of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501


        :return: The deposit_schedule of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :rtype: AnnuityDepositSchedule
        """
        return self._deposit_schedule

    @deposit_schedule.setter
    def deposit_schedule(self, deposit_schedule):
        """Sets the deposit_schedule of this AnnuityCalculatorAccumulationHorizonRequest.


        :param deposit_schedule: The deposit_schedule of this AnnuityCalculatorAccumulationHorizonRequest.  # noqa: E501
        :type: AnnuityDepositSchedule
        """

        self._deposit_schedule = deposit_schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnnuityCalculatorAccumulationHorizonRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnnuityCalculatorAccumulationHorizonRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BeneficiaryBequestConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bequest_duration': 'int',
        'bequest_amount': 'float',
        'years_until_bequest': 'int'
    }

    attribute_map = {
        'bequest_duration': 'bequest_duration',
        'bequest_amount': 'bequest_amount',
        'years_until_bequest': 'years_until_bequest'
    }

    def __init__(self, bequest_duration=10, bequest_amount=None, years_until_bequest=0):  # noqa: E501
        """BeneficiaryBequestConfig - a model defined in Swagger"""  # noqa: E501

        self._bequest_duration = None
        self._bequest_amount = None
        self._years_until_bequest = None
        self.discriminator = None

        if bequest_duration is not None:
            self.bequest_duration = bequest_duration
        self.bequest_amount = bequest_amount
        if years_until_bequest is not None:
            self.years_until_bequest = years_until_bequest

    @property
    def bequest_duration(self):
        """Gets the bequest_duration of this BeneficiaryBequestConfig.  # noqa: E501


        :return: The bequest_duration of this BeneficiaryBequestConfig.  # noqa: E501
        :rtype: int
        """
        return self._bequest_duration

    @bequest_duration.setter
    def bequest_duration(self, bequest_duration):
        """Sets the bequest_duration of this BeneficiaryBequestConfig.


        :param bequest_duration: The bequest_duration of this BeneficiaryBequestConfig.  # noqa: E501
        :type: int
        """
        if bequest_duration is not None and bequest_duration < 1:  # noqa: E501
            raise ValueError("Invalid value for `bequest_duration`, must be a value greater than or equal to `1`")  # noqa: E501

        self._bequest_duration = bequest_duration

    @property
    def bequest_amount(self):
        """Gets the bequest_amount of this BeneficiaryBequestConfig.  # noqa: E501


        :return: The bequest_amount of this BeneficiaryBequestConfig.  # noqa: E501
        :rtype: float
        """
        return self._bequest_amount

    @bequest_amount.setter
    def bequest_amount(self, bequest_amount):
        """Sets the bequest_amount of this BeneficiaryBequestConfig.


        :param bequest_amount: The bequest_amount of this BeneficiaryBequestConfig.  # noqa: E501
        :type: float
        """
        if bequest_amount is None:
            raise ValueError("Invalid value for `bequest_amount`, must not be `None`")  # noqa: E501
        if bequest_amount is not None and bequest_amount < 0:  # noqa: E501
            raise ValueError("Invalid value for `bequest_amount`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bequest_amount = bequest_amount

    @property
    def years_until_bequest(self):
        """Gets the years_until_bequest of this BeneficiaryBequestConfig.  # noqa: E501


        :return: The years_until_bequest of this BeneficiaryBequestConfig.  # noqa: E501
        :rtype: int
        """
        return self._years_until_bequest

    @years_until_bequest.setter
    def years_until_bequest(self, years_until_bequest):
        """Sets the years_until_bequest of this BeneficiaryBequestConfig.


        :param years_until_bequest: The years_until_bequest of this BeneficiaryBequestConfig.  # noqa: E501
        :type: int
        """
        if years_until_bequest is not None and years_until_bequest < 0:  # noqa: E501
            raise ValueError("Invalid value for `years_until_bequest`, must be a value greater than or equal to `0`")  # noqa: E501

        self._years_until_bequest = years_until_bequest

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BeneficiaryBequestConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BeneficiaryBequestConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CardTransactionAuthorizationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'merchant': 'str',
        'partial_auth': 'bool',
        '_date': 'datetime',
        'merchant_category_code': 'int',
        'cleanse_data': 'bool',
        'auth_type': 'list[str]',
        'amount': 'float',
        'transaction_type': 'str',
        'currency_code': 'str',
        'description': 'str',
        'card_id': 'str',
        'merchant_category': 'str'
    }

    attribute_map = {
        'merchant': 'merchant',
        'partial_auth': 'partial_auth',
        '_date': 'date',
        'merchant_category_code': 'merchant_category_code',
        'cleanse_data': 'cleanse_data',
        'auth_type': 'auth_type',
        'amount': 'amount',
        'transaction_type': 'transaction_type',
        'currency_code': 'currency_code',
        'description': 'description',
        'card_id': 'card_id',
        'merchant_category': 'merchant_category'
    }

    def __init__(self, merchant='null', partial_auth=False, _date=None, merchant_category_code=None, cleanse_data=False, auth_type=None, amount=None, transaction_type=None, currency_code=None, description='null', card_id=None, merchant_category='null'):  # noqa: E501
        """CardTransactionAuthorizationRequest - a model defined in Swagger"""  # noqa: E501

        self._merchant = None
        self._partial_auth = None
        self.__date = None
        self._merchant_category_code = None
        self._cleanse_data = None
        self._auth_type = None
        self._amount = None
        self._transaction_type = None
        self._currency_code = None
        self._description = None
        self._card_id = None
        self._merchant_category = None
        self.discriminator = None

        if merchant is not None:
            self.merchant = merchant
        if partial_auth is not None:
            self.partial_auth = partial_auth
        self._date = _date
        if merchant_category_code is not None:
            self.merchant_category_code = merchant_category_code
        if cleanse_data is not None:
            self.cleanse_data = cleanse_data
        self.auth_type = auth_type
        self.amount = amount
        self.transaction_type = transaction_type
        self.currency_code = currency_code
        if description is not None:
            self.description = description
        self.card_id = card_id
        if merchant_category is not None:
            self.merchant_category = merchant_category

    @property
    def merchant(self):
        """Gets the merchant of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The merchant of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._merchant

    @merchant.setter
    def merchant(self, merchant):
        """Sets the merchant of this CardTransactionAuthorizationRequest.


        :param merchant: The merchant of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: str
        """

        self._merchant = merchant

    @property
    def partial_auth(self):
        """Gets the partial_auth of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The partial_auth of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._partial_auth

    @partial_auth.setter
    def partial_auth(self, partial_auth):
        """Sets the partial_auth of this CardTransactionAuthorizationRequest.


        :param partial_auth: The partial_auth of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: bool
        """

        self._partial_auth = partial_auth

    @property
    def _date(self):
        """Gets the _date of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The _date of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this CardTransactionAuthorizationRequest.


        :param _date: The _date of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: datetime
        """
        if _date is None:
            raise ValueError("Invalid value for `_date`, must not be `None`")  # noqa: E501

        self.__date = _date

    @property
    def merchant_category_code(self):
        """Gets the merchant_category_code of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The merchant_category_code of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: int
        """
        return self._merchant_category_code

    @merchant_category_code.setter
    def merchant_category_code(self, merchant_category_code):
        """Sets the merchant_category_code of this CardTransactionAuthorizationRequest.


        :param merchant_category_code: The merchant_category_code of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: int
        """

        self._merchant_category_code = merchant_category_code

    @property
    def cleanse_data(self):
        """Gets the cleanse_data of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The cleanse_data of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._cleanse_data

    @cleanse_data.setter
    def cleanse_data(self, cleanse_data):
        """Sets the cleanse_data of this CardTransactionAuthorizationRequest.


        :param cleanse_data: The cleanse_data of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: bool
        """

        self._cleanse_data = cleanse_data

    @property
    def auth_type(self):
        """Gets the auth_type of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The auth_type of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """Sets the auth_type of this CardTransactionAuthorizationRequest.


        :param auth_type: The auth_type of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: list[str]
        """
        if auth_type is None:
            raise ValueError("Invalid value for `auth_type`, must not be `None`")  # noqa: E501
        allowed_values = ["balance", "spending_control"]  # noqa: E501
        if not set(auth_type).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `auth_type` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(auth_type) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._auth_type = auth_type

    @property
    def amount(self):
        """Gets the amount of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The amount of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CardTransactionAuthorizationRequest.


        :param amount: The amount of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def transaction_type(self):
        """Gets the transaction_type of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The transaction_type of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this CardTransactionAuthorizationRequest.


        :param transaction_type: The transaction_type of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: str
        """
        if transaction_type is None:
            raise ValueError("Invalid value for `transaction_type`, must not be `None`")  # noqa: E501
        allowed_values = ["atm_withdrawal", "purchase"]  # noqa: E501
        if transaction_type not in allowed_values:
            raise ValueError(
                "Invalid value for `transaction_type` ({0}), must be one of {1}"  # noqa: E501
                .format(transaction_type, allowed_values)
            )

        self._transaction_type = transaction_type

    @property
    def currency_code(self):
        """Gets the currency_code of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The currency_code of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this CardTransactionAuthorizationRequest.


        :param currency_code: The currency_code of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: str
        """
        if currency_code is None:
            raise ValueError("Invalid value for `currency_code`, must not be `None`")  # noqa: E501

        self._currency_code = currency_code

    @property
    def description(self):
        """Gets the description of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The description of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CardTransactionAuthorizationRequest.


        :param description: The description of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def card_id(self):
        """Gets the card_id of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The card_id of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._card_id

    @card_id.setter
    def card_id(self, card_id):
        """Sets the card_id of this CardTransactionAuthorizationRequest.


        :param card_id: The card_id of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: str
        """
        if card_id is None:
            raise ValueError("Invalid value for `card_id`, must not be `None`")  # noqa: E501

        self._card_id = card_id

    @property
    def merchant_category(self):
        """Gets the merchant_category of this CardTransactionAuthorizationRequest.  # noqa: E501


        :return: The merchant_category of this CardTransactionAuthorizationRequest.  # noqa: E501
        :rtype: str
        """
        return self._merchant_category

    @merchant_category.setter
    def merchant_category(self, merchant_category):
        """Sets the merchant_category of this CardTransactionAuthorizationRequest.


        :param merchant_category: The merchant_category of this CardTransactionAuthorizationRequest.  # noqa: E501
        :type: str
        """

        self._merchant_category = merchant_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CardTransactionAuthorizationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardTransactionAuthorizationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'w_min_major': 'float',
        'cash_amount': 'float',
        'w_min_minor': 'float',
        'w_max_minor': 'float',
        'w_max_major': 'float'
    }

    attribute_map = {
        'w_min_major': 'w_min_major',
        'cash_amount': 'cash_amount',
        'w_min_minor': 'w_min_minor',
        'w_max_minor': 'w_max_minor',
        'w_max_major': 'w_max_major'
    }

    def __init__(self, w_min_major=None, cash_amount=None, w_min_minor=None, w_max_minor=None, w_max_major=None):  # noqa: E501
        """WConfig - a model defined in Swagger"""  # noqa: E501

        self._w_min_major = None
        self._cash_amount = None
        self._w_min_minor = None
        self._w_max_minor = None
        self._w_max_major = None
        self.discriminator = None

        self.w_min_major = w_min_major
        self.cash_amount = cash_amount
        self.w_min_minor = w_min_minor
        self.w_max_minor = w_max_minor
        self.w_max_major = w_max_major

    @property
    def w_min_major(self):
        """Gets the w_min_major of this WConfig.  # noqa: E501


        :return: The w_min_major of this WConfig.  # noqa: E501
        :rtype: float
        """
        return self._w_min_major

    @w_min_major.setter
    def w_min_major(self, w_min_major):
        """Sets the w_min_major of this WConfig.


        :param w_min_major: The w_min_major of this WConfig.  # noqa: E501
        :type: float
        """
        if w_min_major is None:
            raise ValueError("Invalid value for `w_min_major`, must not be `None`")  # noqa: E501
        if w_min_major is not None and w_min_major > 1:  # noqa: E501
            raise ValueError("Invalid value for `w_min_major`, must be a value less than or equal to `1`")  # noqa: E501
        if w_min_major is not None and w_min_major < 0:  # noqa: E501
            raise ValueError("Invalid value for `w_min_major`, must be a value greater than or equal to `0`")  # noqa: E501

        self._w_min_major = w_min_major

    @property
    def cash_amount(self):
        """Gets the cash_amount of this WConfig.  # noqa: E501


        :return: The cash_amount of this WConfig.  # noqa: E501
        :rtype: float
        """
        return self._cash_amount

    @cash_amount.setter
    def cash_amount(self, cash_amount):
        """Sets the cash_amount of this WConfig.


        :param cash_amount: The cash_amount of this WConfig.  # noqa: E501
        :type: float
        """
        if cash_amount is None:
            raise ValueError("Invalid value for `cash_amount`, must not be `None`")  # noqa: E501
        if cash_amount is not None and cash_amount > 1:  # noqa: E501
            raise ValueError("Invalid value for `cash_amount`, must be a value less than or equal to `1`")  # noqa: E501
        if cash_amount is not None and cash_amount < 0:  # noqa: E501
            raise ValueError("Invalid value for `cash_amount`, must be a value greater than or equal to `0`")  # noqa: E501

        self._cash_amount = cash_amount

    @property
    def w_min_minor(self):
        """Gets the w_min_minor of this WConfig.  # noqa: E501


        :return: The w_min_minor of this WConfig.  # noqa: E501
        :rtype: float
        """
        return self._w_min_minor

    @w_min_minor.setter
    def w_min_minor(self, w_min_minor):
        """Sets the w_min_minor of this WConfig.


        :param w_min_minor: The w_min_minor of this WConfig.  # noqa: E501
        :type: float
        """
        if w_min_minor is None:
            raise ValueError("Invalid value for `w_min_minor`, must not be `None`")  # noqa: E501
        if w_min_minor is not None and w_min_minor > 1:  # noqa: E501
            raise ValueError("Invalid value for `w_min_minor`, must be a value less than or equal to `1`")  # noqa: E501
        if w_min_minor is not None and w_min_minor < 0:  # noqa: E501
            raise ValueError("Invalid value for `w_min_minor`, must be a value greater than or equal to `0`")  # noqa: E501

        self._w_min_minor = w_min_minor

    @property
    def w_max_minor(self):
        """Gets the w_max_minor of this WConfig.  # noqa: E501


        :return: The w_max_minor of this WConfig.  # noqa: E501
        :rtype: float
        """
        return self._w_max_minor

    @w_max_minor.setter
    def w_max_minor(self, w_max_minor):
        """Sets the w_max_minor of this WConfig.


        :param w_max_minor: The w_max_minor of this WConfig.  # noqa: E501
        :type: float
        """
        if w_max_minor is None:
            raise ValueError("Invalid value for `w_max_minor`, must not be `None`")  # noqa: E501
        if w_max_minor is not None and w_max_minor > 1:  # noqa: E501
            raise ValueError("Invalid value for `w_max_minor`, must be a value less than or equal to `1`")  # noqa: E501
        if w_max_minor is not None and w_max_minor < 0:  # noqa: E501
            raise ValueError("Invalid value for `w_max_minor`, must be a value greater than or equal to `0`")  # noqa: E501

        self._w_max_minor = w_max_minor

    @property
    def w_max_major(self):
        """Gets the w_max_major of this WConfig.  # noqa: E501


        :return: The w_max_major of this WConfig.  # noqa: E501
        :rtype: float
        """
        return self._w_max_major

    @w_max_major.setter
    def w_max_major(self, w_max_major):
        """Sets the w_max_major of this WConfig.


        :param w_max_major: The w_max_major of this WConfig.  # noqa: E501
        :type: float
        """
        if w_max_major is None:
            raise ValueError("Invalid value for `w_max_major`, must not be `None`")  # noqa: E501
        if w_max_major is not None and w_max_major > 1:  # noqa: E501
            raise ValueError("Invalid value for `w_max_major`, must be a value less than or equal to `1`")  # noqa: E501
        if w_max_major is not None and w_max_major < 0:  # noqa: E501
            raise ValueError("Invalid value for `w_max_major`, must be a value greater than or equal to `0`")  # noqa: E501

        self._w_max_major = w_max_major

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FinancialPictureRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_date': 'date',
        'client_id': 'str',
        'create_log': 'bool',
        'currency_conversion': 'str',
        'show_history': 'bool',
        'start_date': 'date',
        'currency_code': 'str',
        'show_category_breakdown': 'bool',
        'show_change': 'bool'
    }

    attribute_map = {
        'end_date': 'end_date',
        'client_id': 'client_id',
        'create_log': 'create_log',
        'currency_conversion': 'currency_conversion',
        'show_history': 'show_history',
        'start_date': 'start_date',
        'currency_code': 'currency_code',
        'show_category_breakdown': 'show_category_breakdown',
        'show_change': 'show_change'
    }

    def __init__(self, end_date=None, client_id=None, create_log=False, currency_conversion=None, show_history=False, start_date=None, currency_code=None, show_category_breakdown=True, show_change=False):  # noqa: E501
        """FinancialPictureRequest - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._client_id = None
        self._create_log = None
        self._currency_conversion = None
        self._show_history = None
        self._start_date = None
        self._currency_code = None
        self._show_category_breakdown = None
        self._show_change = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        self.client_id = client_id
        if create_log is not None:
            self.create_log = create_log
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if show_history is not None:
            self.show_history = show_history
        if start_date is not None:
            self.start_date = start_date
        if currency_code is not None:
            self.currency_code = currency_code
        if show_category_breakdown is not None:
            self.show_category_breakdown = show_category_breakdown
        if show_change is not None:
            self.show_change = show_change

    @property
    def end_date(self):
        """Gets the end_date of this FinancialPictureRequest.  # noqa: E501


        :return: The end_date of this FinancialPictureRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this FinancialPictureRequest.


        :param end_date: The end_date of this FinancialPictureRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def client_id(self):
        """Gets the client_id of this FinancialPictureRequest.  # noqa: E501


        :return: The client_id of this FinancialPictureRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this FinancialPictureRequest.


        :param client_id: The client_id of this FinancialPictureRequest.  # noqa: E501
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def create_log(self):
        """Gets the create_log of this FinancialPictureRequest.  # noqa: E501


        :return: The create_log of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this FinancialPictureRequest.


        :param create_log: The create_log of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this FinancialPictureRequest.  # noqa: E501


        :return: The currency_conversion of this FinancialPictureRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this FinancialPictureRequest.


        :param currency_conversion: The currency_conversion of this FinancialPictureRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def show_history(self):
        """Gets the show_history of this FinancialPictureRequest.  # noqa: E501


        :return: The show_history of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_history

    @show_history.setter
    def show_history(self, show_history):
        """Sets the show_history of this FinancialPictureRequest.


        :param show_history: The show_history of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._show_history = show_history

    @property
    def start_date(self):
        """Gets the start_date of this FinancialPictureRequest.  # noqa: E501


        :return: The start_date of this FinancialPictureRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this FinancialPictureRequest.


        :param start_date: The start_date of this FinancialPictureRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def currency_code(self):
        """Gets the currency_code of this FinancialPictureRequest.  # noqa: E501


        :return: The currency_code of this FinancialPictureRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this FinancialPictureRequest.


        :param currency_code: The currency_code of this FinancialPictureRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def show_category_breakdown(self):
        """Gets the show_category_breakdown of this FinancialPictureRequest.  # noqa: E501


        :return: The show_category_breakdown of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_category_breakdown

    @show_category_breakdown.setter
    def show_category_breakdown(self, show_category_breakdown):
        """Sets the show_category_breakdown of this FinancialPictureRequest.


        :param show_category_breakdown: The show_category_breakdown of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._show_category_breakdown = show_category_breakdown

    @property
    def show_change(self):
        """Gets the show_change of this FinancialPictureRequest.  # noqa: E501


        :return: The show_change of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_change

    @show_change.setter
    def show_change(self, show_change):
        """Sets the show_change of this FinancialPictureRequest.


        :param show_change: The show_change of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._show_change = show_change

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FinancialPictureRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FinancialPictureRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
